@@ -46,7 +46,7 @@ See https://github.com/BonnieMcLean/IcoTools for more details."""
     # get their feature values
     features={}
     here=os.path.dirname(os.path.abspath(__file__))
-    path=os.path.join(here,'features','phoiblefeatures.txt')
+    path=os.path.join(here,'templates','phoiblefeatures.txt')
     with open(path,"r",encoding="UTF-8") as infile:
         next(infile)
         reader=csv.reader(infile)
